﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using TodoList.Desktop.Model;
using TodoList.Persistence;

namespace TodoList.Desktop.ViewModel
{
    public class TodoListViewModel : ViewModelBase
    {
        private ObservableCollection<List> _lists;
        private ObservableCollection<Item> _items;
        private readonly ITodoListService _service;

        public ObservableCollection<List> Lists
        {
            get => _lists;
	        set
            {
                _lists = value;
                OnPropertyChanged();
            }
        }

        public ObservableCollection<Item> Items
        {
            get => _items;
	        set
            {
                _items = value;
                OnPropertyChanged();
            }
        }

        public DelegateCommand SelectCommand { get; private set; }

        public TodoListViewModel(ITodoListService service)
        {
            _service = service;
            LoadAsync();

            SelectCommand = new DelegateCommand(
                async param =>
                {
                    Items = new ObservableCollection<Item>(await _service.LoadItemsAsync(((List)param).Id));
                });
        }

        public async void LoadAsync()
        {
            Lists = new ObservableCollection<List>(await _service.LoadListsAsync());
        }
    }
}
