﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.AspNetCore.Mvc;
using Microsoft.AspNetCore.Mvc.Rendering;
using Microsoft.EntityFrameworkCore;
using TodoList.Persistence;

namespace TodoList.WebSite.Controllers
{
	public class ItemsController : Controller
	{
		private readonly TodoListContext _context;

		public ItemsController(TodoListContext context)
		{
			_context = context;
		}

		// GET: Items/Create
		public IActionResult Create()
		{
			ViewData["ListId"] = new SelectList(_context.Lists.OrderBy(l => l.Name), "Id", "Name", TempData["ListId"]);
			return View();
		}

		// POST: Items/Create
		[HttpPost]
		[ValidateAntiForgeryToken]
		public IActionResult Create(Item item)
		{
			if (ModelState.IsValid)
			{
				_context.Add(item);
				_context.SaveChanges();
				return RedirectToAction("Details", "Lists", new { id = item.ListId });
			}

			ViewData["ListId"] = new SelectList(_context.Lists.OrderBy(l => l.Name), "Id", "Name", item.ListId);
			return View(item);
		}

		// GET: Items/Edit/5
		public IActionResult Edit(int? id)
		{
			if (id == null)
			{
				return BadRequest();
			}

			var item = _context.Items.Find(id);
			if (item == null)
			{
				return NotFound();
			}

			ViewData["ListId"] = new SelectList(_context.Lists.OrderBy(l => l.Name), "Id", "Name", item.ListId);
			return View(item);
		}

		// POST: Items/Edit/5
		[HttpPost]
		[ValidateAntiForgeryToken]
		public IActionResult Edit(int id, Item item)
		{
			if (id != item.Id)
			{
				return BadRequest();
			}

			if (ModelState.IsValid)
			{
				try
				{
					_context.Update(item);
					_context.SaveChanges();
				}
				catch (DbUpdateConcurrencyException)
				{
					if (!ItemExists(item.Id))
					{
						return NotFound();
					}
					else
					{
						throw;
					}
				}

				return RedirectToAction("Details", "Lists", new { id = item.ListId });
			}

			ViewData["ListId"] = new SelectList(_context.Lists.OrderBy(l => l.Name), "Id", "Name", item.ListId);
			return View(item);
		}

		// GET: Items/Delete/5
		public IActionResult Delete(int? id)
		{
			if (id == null)
			{
				return BadRequest();
			}

			var item = _context.Items
				.Include(i => i.List)
				.SingleOrDefault(m => m.Id == id);
			if (item == null)
			{
				return NotFound();
			}

			return View(item);
		}

		// POST: Items/Delete/5
		[HttpPost, ActionName("Delete")]
		[ValidateAntiForgeryToken]
		public IActionResult DeleteConfirmed(int id)
		{
			var item = _context.Items.Find(id);
			_context.Items.Remove(item);
			_context.SaveChangesAsync();
			return RedirectToAction("Details", "Lists", new { id = item.ListId });
		}

		private bool ItemExists(int id)
		{
			return _context.Items.Any(e => e.Id == id);
		}
	}
}
