﻿using System;
using System.Collections.Generic;
using System.Linq;
using Microsoft.AspNetCore.Mvc;
using Microsoft.EntityFrameworkCore;
using TodoList.Persistence;

namespace TodoList.WebSite.Controllers
{
	public class ListsController : Controller
	{
		private readonly TodoListContext _context;

		public ListsController(TodoListContext context)
		{
			_context = context;
		}

		// GET: Lists
		public IActionResult Index()
		{
			return View(_context.Lists.OrderBy(l => l.Name).ToList());
		}

		// GET: Lists/Details/5
		public IActionResult Details(int? id)
		{
			if (id == null)
			{
				return BadRequest();
			}

			var list = _context.Lists
				.Include(m => m.Items)
				.SingleOrDefault(m => m.Id == id);
			if (list == null)
			{
				return NotFound();
			}

			return View(list);
		}

		// GET: Lists/Create
		public IActionResult Create()
		{
			return View();
		}

		// POST: Lists/Create
		[HttpPost]
		[ValidateAntiForgeryToken]
		public IActionResult Create(List list)
		{
			if (ModelState.IsValid)
			{
				_context.Add(list);
				_context.SaveChangesAsync();
				return RedirectToAction(nameof(Index));
			}

			return View(list);
		}

		// GET: Lists/Edit/5
		public IActionResult Edit(int? id)
		{
			if (id == null)
			{
				return BadRequest();
			}

			var list = _context.Lists.Find(id);
			if (list == null)
			{
				return NotFound();
			}

			return View(list);
		}

		// POST: Lists/Edit/5
		[HttpPost]
		[ValidateAntiForgeryToken]
		public IActionResult Edit(int id, List list)
		{
			if (id != list.Id)
			{
				return BadRequest();
			}

			if (ModelState.IsValid)
			{
				try
				{
					_context.Update(list);
					_context.SaveChangesAsync();
				}
				catch (DbUpdateConcurrencyException)
				{
					if (!ListExists(list.Id))
					{
						return NotFound();
					}
					else
					{
						throw;
					}
				}

				return RedirectToAction(nameof(Index));
			}

			return View(list);
		}

		// GET: Lists/Delete/5
		public IActionResult Delete(int? id)
		{
			if (id == null)
			{
				return BadRequest();
			}

			var list = _context.Lists.Find(id);
			if (list == null)
			{
				return NotFound();
			}

			return View(list);
		}

		// POST: Lists/Delete/5
		[HttpPost, ActionName("Delete")]
		[ValidateAntiForgeryToken]
		public IActionResult DeleteConfirmed(int id)
		{
			var list = _context.Lists.Find(id);
			_context.Lists.Remove(list);
			_context.SaveChangesAsync();
			return RedirectToAction(nameof(Index));
		}

		// GET: Lists/CreateItem/5
		public IActionResult CreateItem(int id)
		{
			TempData["ListId"] = id; // Akciók közti információátadásnál a ViewData és ViewBag nem használható.
			return RedirectToAction("Create", "Items");
		}


		private bool ListExists(int id)
		{
			return _context.Lists.Any(e => e.Id == id);
		}
	}
}
